# -*- coding: UTF-8 -*-
"""
This module implements a spiking neural network.
Neurons are based on the model described by:
    
Izhikevich, E. M.
Simple Model of Spiking Neurons
IEEE TRANSACTIONS ON NEURAL NETWORKS, VOL. 14, NO. 6, NOVEMBER 2003
"""

from iznn_pure import Neuron, Synapse
from network import Network, create_phenotype
